==> jsoncons-0.177.0.tar.gz: jsoncons-0.177.0/doc/Reference.md <==
All core jsoncons classes and functions are in namespace `jsoncons`.  

#### Variant-like Data Structure

[basic_json](ref/corelib/basic_json.md)  

#### Serialize and Deserialize Support

[json_type_traits](ref/corelib/json_type_traits.md)  
[encode_json](ref/corelib/encode_json.md)  
[decode_json](ref/corelib/decode_json.md)  
[basic_json_options](ref/corelib/basic_json_options.md)    

#### Streaming API for JSON (StAJ)

[staj_cursor](ref/corelib/staj_cursor.md)  
[staj_event](ref/corelib/staj_event.md)  
[staj_object_iterator](ref/corelib/staj_object_iterator.md)  
[staj_array_iterator](ref/corelib/staj_array_iterator.md)  

[basic_json_cursor](ref/corelib/basic_json_cursor.md)  
[basic_json_encoder](ref/corelib/basic_json_encoder.md)  

#### Push Parsing API

[basic_json_visitor](ref/corelib/basic_json_visitor.md)  

[json_parser](ref/corelib/json_parser.md)  
[basic_json_reader](ref/corelib/basic_json_reader.md)  

[json_decoder](ref/corelib/json_decoder.md)  

[basic_json_filter](ref/corelib/basic_json_filter.md)  
[rename_object_key_filter](ref/corelib/rename_object_key_filter.md)  

### Extensions

#### [jsonpointer](ref/jsonpointer/jsonpointer.md)

#### [jsonpatch](ref/jsonpatch/jsonpatch.md)

#### [jsonpath](ref/jsonpath/jsonpath.md)

#### [bson](ref/bson/bson.md)

#### [cbor](ref/cbor/cbor.md)

#### [msgpack](ref/msgpack/msgpack.md)

#### [ubjson](ref/ubjson/ubjson.md)

### Tutorials

[Basics](Tutorials/Basics.md)

[Custom Allocators](Tutorials/Custom%20Allocators.md)

[Unicode support](Tutorials/Unicode%20support.md)

==> jsoncons_1.3.2.orig.tar.gz: jsoncons-1.3.2/doc/Reference.md <==
All core jsoncons classes and functions are in namespace `jsoncons`.  

#### Variant-like Data Structure

[basic_json](ref/corelib/basic_json.md)  

#### Serialize and Deserialize Support

[json_type_traits](ref/corelib/json_type_traits.md)  
[encode_json](ref/corelib/encode_json.md)  
[decode_json](ref/corelib/decode_json.md)  
[basic_json_options](ref/corelib/basic_json_options.md)    

#### Streaming API for JSON (StAJ)

[staj_cursor](ref/corelib/staj_cursor.md)  
[basic_staj_event](ref/corelib/basic_staj_event.md)  
[staj_object_iterator](ref/corelib/staj_object_iterator.md)  
[staj_array_iterator](ref/corelib/staj_array_iterator.md)  

[basic_json_cursor](ref/corelib/basic_json_cursor.md)  
[basic_json_encoder](ref/corelib/basic_json_encoder.md)  

#### Push Parsing API

[basic_json_visitor](ref/corelib/basic_json_visitor.md)  

[basic_json_parser](ref/corelib/basic_json_parser.md)  
[basic_json_reader](ref/corelib/basic_json_reader.md)  

[json_decoder](ref/corelib/json_decoder.md)  

[basic_json_filter](ref/corelib/basic_json_filter.md)  
[rename_object_key_filter](ref/corelib/rename_object_key_filter.md)  

### Extensions

#### [jsonpointer](ref/jsonpointer/jsonpointer.md)

#### [jsonpatch](ref/jsonpatch/jsonpatch.md)

#### [jsonpath](ref/jsonpath/jsonpath.md)

#### [bson](ref/bson/bson.md)

#### [cbor](ref/cbor/cbor.md)

#### [msgpack](ref/msgpack/msgpack.md)

#### [ubjson](ref/ubjson/ubjson.md)

### Tutorials

[Basics](Tutorials/Basics.md)

[Unicode support](Tutorials/Unicode%20support.md)
